nx.data.VertexSet - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.data.VertexSet Class

Extends nx.data.Vertex
Module: nx.data

Vertex set ckass

- Index
- Methods
- Properties
- Events

## Item Index

### Methods

- addEdgeSet
- addVertex
- clearBinding
- dispose
- eachConnectedVertex
- get
- getBinding
- getData
- gets
- has
- notify
- removeEdgeSet
- set
- setBinding
- translate
- unwatch

### Properties

- connectedVertices
- edges
- edgeSetCollections
- edgeSets
- generated
- generatedRootVertexSet
- graph
- id
- parentVertexSet
- position
- positionGetter
- positionSetter
- rootVertexSet
- type
- updated
- vertices
- visible
- x
- y

### Events

- updateVertexSetCoordinate

## Methods

### `addEdgeSet`

(

- `edgeSet`
- `linkKey`

)

Inherited from nx.data.Vertex:

Add connected edgeSet, which source vertex is this vertex

#### Parameters:

- `edgeSet` nx.data.EdgeSet
- `linkKey` String

### `addVertex`

(

- `vertex`

)

Add child vertex

#### Parameters:

- `vertex` Object

### `clearBinding`

(

- `prop`

)

Inherited from nx.Observable:

Clear binding for specified property.

#### Parameters:

- `prop` Object

### ``

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

### `dispose`

()

Inherited from nx.Observable

Dispose current object.

### `eachConnectedVertex`

(

- `callback`
- `context`

)

Inherited from nx.data.Vertex:

Iterate all connected vertices

#### Parameters:

- `callback` Function
- `context` Object

### `get`

(

- `name`

)

Inherited from nx.data.ObservableObject:

Get specified property value.

#### Parameters:

- `name` String

#### Returns:

:

### `getBinding`

(

- `prop`

)

Inherited from nx.Observable:

Get existing binding object for specified property.

#### Parameters:

- `prop` Object

#### Returns:

:

### `getData`

() Object

Inherited from nx.data.Vertex:

Get original data

#### Returns:

Object:

### `gets`

() Object

Inherited from nx.data.ObservableObject:

Get all properties.

#### Returns:

Object:

### `has`

(

- `name`

)
Boolean

Inherited from nx.data.ObservableObject:

Check whether current object has specified property.

#### Parameters:

- `name` String

#### Returns:

Boolean:

### `notify`

(

- `names`
- `oldValue`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `oldValue` Object

### `removeEdgeSet`

(

- `linkKey`

)

Inherited from nx.data.Vertex:

Remove edgeSet from connected edges array

#### Parameters:

- `linkKey` String

### `set`

(

- `name`
- `value`

)

Inherited from nx.data.ObservableObject:

Set specified property value.

#### Parameters:

- `name` String
- `value`

### `setBinding`

(

- `prop`
- `expr`
- `source`

)

Inherited from nx.Observable:

Set binding for specified property.

#### Parameters:

- `prop` Object
- `expr` Object
- `source` Object

### `translate`

(

- `x`
- `y`

)

Inherited from nx.data.Vertex:

Move vertex

#### Parameters:

- `x` Object
- `y` Object

### `unwatch`

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

## Properties

### `connectedVertices`

Unknown

Inherited from nx.data.Vertex:

Get connected vertices

### `edges`

Unknown

Inherited from nx.data.Vertex:

Get connected edges

### `edgeSetCollections`

Unknown

Inherited from nx.data.Vertex:

connected edgeSetCollections

### `edgeSets`

Unknown

Inherited from nx.data.Vertex:

connected edgeSets

### `generated`

Boolean

Inherited from nx.data.Vertex:

Status property,tag is this vertex generated

Default: false

### `generatedRootVertexSet`

Unknown

Inherited from nx.data.Vertex:

Generated Root VertexSet

### `graph`

nx.data.ObservableGraph

Inherited from nx.data.Vertex:

Graph instance

### `id`

String | Number

Inherited from nx.data.Vertex:

Vertex id

### `parentVertexSet`

nx.data.VertexSet

Inherited from nx.data.Vertex:

Vertex parent vertex set, if exist

### `position`

Unknown

Inherited from nx.data.Vertex:

Get/set vertex position.

### `positionGetter`

Unknown

Inherited from nx.data.Vertex:

### `positionSetter`

Unknown

Inherited from nx.data.Vertex:

### `rootVertexSet`

Unknown

Inherited from nx.data.Vertex:

Vertex root vertexSet

### `type`

String

Inherited from nx.data.Vertex

VertexSet's type

Default: 'vertexset'

### `updated`

Boolean

Inherited from nx.data.Vertex:

Status property,tag is this vertex updated

Default: false

### `vertices`

Object

All child vertices

Default: {}

### `visible`

Boolean

Inherited from nx.data.Vertex:

Set/get vertex's visibility, and this property related to all connect edge set

Default: true

### `x`

Unknown

Inherited from nx.data.Vertex:

Get/set x coordination, suggest use position property

### `y`

Unknown

Inherited from nx.data.Vertex:

Get/set y coordination, suggest use position property

## Events

### `updateVertexSetCoordinate`

#### Event Payload:

- `sender` Object

  Trigger instance

- `{oldPosition:Point,newPosition:Point}` Object